#ifndef SPLUNK_STATUS_H
#define SPLUNK_STATUS_H

#include <Plasma/Applet>

#include <QProcess>

struct InstanceInfo {
  InstanceInfo() : user("admin"), pass("changeme"), useSSL(true) {}
  QString           user;
  QString           pass;
  QStringList       messages;
  bool              useSSL;
};

class RestProcess : public QProcess
{
  public:
    RestProcess(const QString& id) : QProcess(), _id(id) {}
    const QString& getInstanceId() const {return _id;}
  private:
    QString         _id;
};

class StatusApplet : public Plasma::Applet
{
  Q_OBJECT
  public:
    StatusApplet(QObject* parent, const QVariantList& args);
    ~StatusApplet();

    void init();

  public slots:
    void procFinished(int exitCode, QProcess::ExitStatus exitStatus);
    void updateMessages();

  private:
    void updateDisplay(const unsigned& row, const QStringList& messages);
    // clears the passed-in message list before updating.
    // return true == retrieved 0 or more messages, false == failed to retrieve.
    bool getMessages(const QString& id);
    void loadSettings();

  private:
    unsigned                        _interval;              // milliseconds.
    QGraphicsGridLayout*            _layout;
    QTimer*                         _timer;
    QStringList                     _uriList;

    QString                         _binPath;
    QMap<QString, InstanceInfo>     _instanceInfoMap;       // map of host:port to settings & messages.
    QMap<unsigned, unsigned>        _rowHeightMap;
};

#endif // SPLUNK_STATUS_H
